/*
** Module   : TitledElement.java
** Abstract : Groups attributes associated with titles.
**
** Copyright (c) 2020, Golden Code Development Corporation.
**
** -#- -I- --Date-- ----------------------------Description--------------------------------------
** 001 GES 20200220 Created initial version.
*/

/*
** This program is free software: you can redistribute it and/or modify
** it under the terms of the GNU Affero General Public License as
** published by the Free Software Foundation, either version 3 of the
** License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU Affero General Public License for more details.
**
** You may find a copy of the GNU Affero GPL version 3 at the following
** location: https://www.gnu.org/licenses/agpl-3.0.en.html
** 
** Additional terms under GNU Affero GPL version 3 section 7:
** 
**   Under Section 7 of the GNU Affero GPL version 3, the following additional
**   terms apply to the works covered under the License.  These additional terms
**   are non-permissive additional terms allowed under Section 7 of the GNU
**   Affero GPL version 3 and may not be removed by you.
** 
**   0. Attribution Requirement.
** 
**     You must preserve all legal notices or author attributions in the covered
**     work or Appropriate Legal Notices displayed by works containing the covered
**     work.  You may not remove from the covered work any author or developer
**     credit already included within the covered work.
** 
**   1. No License To Use Trademarks.
** 
**     This license does not grant any license or rights to use the trademarks
**     Golden Code, FWD, any Golden Code or FWD logo, or any other trademarks
**     of Golden Code Development Corporation. You are not authorized to use the
**     name Golden Code, FWD, or the names of any author or contributor, for
**     publicity purposes without written authorization.
** 
**   2. No Misrepresentation of Affiliation.
** 
**     You may not represent yourself as Golden Code Development Corporation or FWD.
** 
**     You may not represent yourself for publicity purposes as associated with
**     Golden Code Development Corporation, FWD, or any author or contributor to
**     the covered work, without written authorization.
** 
**   3. No Misrepresentation of Source or Origin.
** 
**     You may not represent the covered work as solely your work.  All modified
**     versions of the covered work must be marked in a reasonable way to make it
**     clear that the modified work is not originating from Golden Code Development
**     Corporation or FWD.  All modified versions must contain the notices of
**     attribution required in this license.
*/

package com.goldencode.p2j.ui;

import com.goldencode.p2j.util.*;

/**
 * Groups attributes associated with titles.
 */
public interface TitledElement
{
   /**
    * Gets the TITLE-BGCOLOR writable attribute.
    *
    * @return   The current value of the TITLE-BGCOLOR attribute.
    */
   @LegacyAttribute(name = "TITLE-BGCOLOR")
   public integer getTitleBgColor();

   /**
    * Sets the TITLE-BGCOLOR writable attribute.
    *
    * @param    bgcolor
    *           The new value for the TITLE-BGCOLOR attribute.
    */
   @LegacyAttribute(name = "TITLE-BGCOLOR", setter = true)
   public void setTitleBgColor(int64 bgcolor);

   /**
    * Sets the TITLE-BGCOLOR writable attribute.
    *
    * @param    bgcolor
    *           The new value for the TITLE-BGCOLOR attribute.
    */
   @LegacyAttribute(name = "TITLE-BGCOLOR", setter = true)
   public void setTitleBgColor(long bgcolor);

   /**
    * Gets the TITLE-DCOLOR writable attribute.
    *
    * @return   The current value of the TITLE-DCOLOR attribute.
    */
   @LegacyAttribute(name = "TITLE-DCOLOR")
   public integer getTitleDColor();

   /**
    * Sets the TITLE-DCOLOR writable attribute.
    *
    * @param    dcolor
    *           The new value for the TITLE-DCOLOR attribute.
    */
   @LegacyAttribute(name = "TITLE-DCOLOR", setter = true)
   public void setTitleDColor(int64 dcolor);

   /**
    * Sets the TITLE-DCOLOR writable attribute.
    *
    * @param    dcolor
    *           The new value for the TITLE-DCOLOR attribute.
    */
   @LegacyAttribute(name = "TITLE-DCOLOR", setter = true)
   public void setTitleDColor(long dcolor);

   /**
    * Gets the TITLE-FGCOLOR writable attribute.
    *
    * @return   The current value of the TITLE-FGCOLOR attribute.
    */
   @LegacyAttribute(name = "TITLE-FGCOLOR")
   public integer getTitleFgColor();

   /**
    * Sets the TITLE-FGCOLOR writable attribute.
    *
    * @param    fgcolor
    *           The new value for the TITLE-FGCOLOR attribute.
    */
   @LegacyAttribute(name = "TITLE-FGCOLOR", setter = true)
   public void setTitleFgColor(int64 fgcolor);

   /**
    * Sets the TITLE-FGCOLOR writable attribute.
    *
    * @param    fgcolor
    *           The new value for the TITLE-FGCOLOR attribute.
    */
   @LegacyAttribute(name = "TITLE-FGCOLOR", setter = true)
   public void setTitleFgColor(long fgcolor);

   /**
    * Get the TITLE-FONT attribute of this browse column widget.
    *
    * @return   A value representing an entry in the user's font-table.
    */
   @LegacyAttribute(name = "TITLE-FONT")
   public integer getTitleFont();

   /**
    * Set the TITLE-FONT attribute of this browse widget.
    *
    * @param    fontNum
    *           An entry in the font-table or unknown to refer the default font.
    */
   @LegacyAttribute(name = "TITLE-FONT", setter = true)
   public void setTitleFont(int64 fontNum);

   /**
    * Set the TITLE-FONT attribute of this browse widget.
    *
    * @param    font
    *           An entry in the font-table or unknown to refer the default font.
    */
   @LegacyAttribute(name = "TITLE-FONT", setter = true)
   public void setTitleFont(long font);
}